package logic

import (
	"errors"
	"fusenapi/model/gmodel"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
	"gorm.io/gorm"
)

type SaveLdapGroupLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewSaveLdapGroupLogic(ctx context.Context, svcCtx *svc.ServiceContext) *SaveLdapGroupLogic {
	return &SaveLdapGroupLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *SaveLdapGroupLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *SaveLdapGroupLogic) SaveLdapGroup(req *types.SaveLdapGroupReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	// 返回值必须调用Set重新返回, resp可以空指针调用 resp.SetStatus(basic.CodeOK, data)
	// userinfo 传入值时, 一定不为null

	var err1 error
	if req.Id > 0 {
		resOne, err := l.svcCtx.AllModels.LdapGroup.FindOneById(l.ctx, req.Id)
		if err != nil {
			if errors.Is(err, gorm.ErrRecordNotFound) {
				basic.CodeServiceErr.Message = "记录不存在"
			} else {
				basic.CodeServiceErr.Message = "系统出错"
			}
			return resp.SetStatus(basic.CodeServiceErr)
		}
		var updateMap = make(map[string]interface{})
		if req.Name != "" {
			updateMap["name"] = req.Name
		}
		if req.Type != "" {
			updateMap["type"] = req.Type
		}
		if req.Keyword != "" {
			updateMap["keyword"] = req.Keyword
		}
		if req.Remark != "" {
			updateMap["remark"] = req.Remark
		}
		if req.Status != 0 {
			updateMap["status"] = req.Status
		}
		if req.Sort != 0 {
			updateMap["sort"] = req.Sort
		}
		err1 = l.svcCtx.AllModels.LdapGroup.UpdateOne(l.ctx, resOne, updateMap)
	} else {
		err1 = l.svcCtx.AllModels.LdapGroup.InsertOne(l.ctx, gmodel.LdapGroup{
			Type:    &req.Type,
			Name:    &req.Name,
			Keyword: &req.Keyword,
			Remark:  &req.Remark,
			Status:  &req.Status,
			Sort:    &req.Sort,
		})
	}
	if err1 != nil {
		basic.CodeServiceErr.Message = "系统出错"
		return resp.SetStatus(basic.CodeServiceErr)
	}
	return resp.SetStatus(basic.CodeOK)
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *SaveLdapGroupLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
